package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.DBUtils;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaOfficeContact;
import com.huiju.estateagents.service.ITaOfficeContactService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;
import java.util.Map;

/**
 * <p>
    * 联系咨询  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-06-11
 */
@RestController
@RequestMapping("/api")
public class TaOfficeContactController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOfficeContactController.class);

    private final static String SEQ_PREFIX = "office-web";

    @Autowired
    public ITaOfficeContactService iTaOfficeContactService;

    @Autowired
    public DBUtils dbUtils;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/channel/taOfficeContact",method= RequestMethod.GET)
    public ResponseBean taOfficeContactList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                            @RequestParam(value ="company",required = false) String company,
                                            @RequestParam(value ="name",required = false) String name,
                                            @RequestParam(value ="phone",required = false) String phone,
                                            @RequestParam(value ="status",required = false) Integer status
                                            ){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaOfficeContact> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaOfficeContact> queryWrapper = new QueryWrapper<>();
            queryWrapper.like(!StringUtils.isEmpty(company),"company",company);
            queryWrapper.like(!StringUtils.isEmpty(name),"name",name);
            queryWrapper.like(!StringUtils.isEmpty(phone),"phone",phone);
            queryWrapper.eq(null != status,"status",status);
            queryWrapper.gt("status", CommConstant.STATUS_DELETE);
            queryWrapper.orderByDesc("create_date");

            IPage<TaOfficeContact> result = iTaOfficeContactService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOfficeContactList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @return
     */
    @CrossOrigin(origins = "*", maxAge = 3600)
    @RequestMapping(value="/official/taOfficeContact",method= RequestMethod.POST)
    public ResponseBean taOfficeContactAdd(@RequestBody TaOfficeContact taOfficeContact){
        ResponseBean responseBean = new ResponseBean();
        try {
            // 主键格式 20200611001  日期 + 数字,  数字 3 位, 前面补 0
            String today = DateUtils.todayCompact();
            Integer no = dbUtils.nextVal(SEQ_PREFIX + "-" + today);
            taOfficeContact.setSerialNo(StringUtils.lpad(no.toString(), "0", 3));
            taOfficeContact.setCreateDate(LocalDateTime.now());
            taOfficeContact.setStatus(CommConstant.STATUS_NORMAL);
            if (iTaOfficeContactService.save(taOfficeContact)){
                responseBean.addSuccess(taOfficeContact);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOfficeContactAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
//
//    /**
//     * 保存对象
//     *
//     * @return
//     */
//    @RequestMapping(value="/official/taOfficeContact",method= RequestMethod.OPTIONS)
//    public ResponseBean taOfficeContactOptions(HttpServletRequest request, HttpServletResponse response){
//        //跨域请求，*代表允许全部类型
//        response.setHeader("Access-Control-Allow-Origin", "*");
//        //允许请求方式
//        response.setHeader("Access-Control-Allow-Methods", "POST, GET, OPTIONS, DELETE");
//        //用来指定本次预检请求的有效期，单位为秒，在此期间不用发出另一条预检请求
//        response.setHeader("Access-Control-Max-Age", "3600");
//        //请求包含的字段内容，如有多个可用哪个逗号分隔如下
//        response.setHeader("Access-Control-Allow-Headers", "content-type,x-requested-with,Authorization, x-ui-request,lang");
//        //访问控制允许凭据，true为允许
//        response.setHeader("Access-Control-Allow-Credentials", "true");
//        response.setCharacterEncoding("utf-8");
//
//        return ResponseBean.success("success");
//    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taOfficeContact/{id}", method= RequestMethod.DELETE)
    public ResponseBean taOfficeContactDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaOfficeContactService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOfficeContactDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taOfficeContact 实体对象
     * @return
     */
    @RequestMapping(value="/taOfficeContact/{id}",method= RequestMethod.PUT)
    public ResponseBean taOfficeContactUpdate(@PathVariable String id,
                                        @RequestBody TaOfficeContact taOfficeContact){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOfficeContactService.updateById(taOfficeContact)){
                responseBean.addSuccess(taOfficeContact);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOfficeContactUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taOfficeContact/{id}",method= RequestMethod.GET)
    public ResponseBean taOfficeContactGet(@PathVariable String id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaOfficeContactService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOfficeContactDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
